@@ -1,9 +1,11 @@
 """libtmux pytest plugin."""
+
+from __future__ import annotations
+
 import contextlib
 import getpass
 import logging
 import os
-import pathlib
 import typing as t
 
 import pytest
@@ -13,6 +15,8 @@ from libtmux.server import Server
 from libtmux.test import TEST_SESSION_PREFIX, get_test_session_name, namer
 
 if t.TYPE_CHECKING:
+    import pathlib
+
     from libtmux.session import Session
 
 logger = logging.getLogger(__name__)
@@ -104,7 +108,7 @@ def clear_env(monkeypatch: pytest.MonkeyPatch) -> None:
             monkeypatch.delenv(k)
 
 
-@pytest.fixture(scope="function")
+@pytest.fixture
 def server(
     request: pytest.FixtureRequest,
     monkeypatch: pytest.MonkeyPatch,
@@ -135,7 +139,7 @@ def server(
 
         >>> result.assert_outcomes(passed=1)
     """
-    server = Server(socket_name="libtmux_test%s" % next(namer))
+    server = Server(socket_name=f"libtmux_test{next(namer)}")
 
     def fin() -> None:
         server.kill()
@@ -145,8 +149,8 @@ def server(
     return server
 
 
-@pytest.fixture(scope="function")
-def session_params() -> t.Dict[str, t.Any]:
+@pytest.fixture
+def session_params() -> dict[str, t.Any]:
     """Return new, temporary :class:`libtmux.Session`.
 
     >>> import pytest
@@ -183,12 +187,12 @@ def session_params() -> t.Dict[str, t.Any]:
     return {}
 
 
-@pytest.fixture(scope="function")
+@pytest.fixture
 def session(
     request: pytest.FixtureRequest,
-    session_params: t.Dict[str, t.Any],
+    session_params: dict[str, t.Any],
     server: Server,
-) -> "Session":
+) -> Session:
     """Return new, temporary :class:`libtmux.Session`.
 
     >>> from libtmux.session import Session
