@@ -1,7 +1,12 @@
 """Tests for libtmux pytest plugin."""
-import textwrap
 
-import pytest
+from __future__ import annotations
+
+import textwrap
+import typing as t
+
+if t.TYPE_CHECKING:
+    import pytest
 
 
 def test_plugin(
