@@ -1,8 +1,11 @@
 """Test for libtmux Window object."""
 
+from __future__ import annotations
+
 import logging
 import shutil
 import time
+import typing as t
 
 import pytest
 
@@ -16,9 +19,11 @@ from libtmux.constants import (
 )
 from libtmux.pane import Pane
 from libtmux.server import Server
-from libtmux.session import Session
 from libtmux.window import Window
 
+if t.TYPE_CHECKING:
+    from libtmux.session import Session
+
 logger = logging.getLogger(__name__)
 
 
@@ -456,9 +461,9 @@ def test_split_with_environment_logs_warning_for_old_tmux(
         environment={"ENV_VAR": "pane"},
     )
 
-    assert any(
-        "Environment flag ignored" in record.msg for record in caplog.records
-    ), "Warning missing"
+    assert any("Environment flag ignored" in record.msg for record in caplog.records), (
+        "Warning missing"
+    )
 
 
 @pytest.mark.skipif(
@@ -591,10 +596,10 @@ def test_new_window_with_direction_logs_warning_for_old_tmux(
         direction=WindowDirection.After,
     )
 
-    assert any(
-        "Window target ignored" in record.msg for record in caplog.records
-    ), "Warning missing"
+    assert any("Window target ignored" in record.msg for record in caplog.records), (
+        "Warning missing"
+    )
 
-    assert any(
-        "Direction flag ignored" in record.msg for record in caplog.records
-    ), "Warning missing"
+    assert any("Direction flag ignored" in record.msg for record in caplog.records), (
+        "Warning missing"
+    )
